{
  am_pm_abbreviated => [
    "am",
    "pm",
  ],
  available_formats => {
    Bh => "h '\N{U+0447}'. B",
    Bhm => "h:mm '\N{U+0447}'. B",
    Bhms => "h:mm:ss '\N{U+0447}'. B",
    E => "ccc",
    EBhm => "E, h:mm '\N{U+0447}'. B",
    EBhms => "E, h:mm:ss '\N{U+0447}'. B",
    EHm => "E, HH:mm '\N{U+0447}'.",
    EHms => "E, HH:mm:ss '\N{U+0447}'.",
    Ed => "E, d",
    Ehm => "E, h:mm '\N{U+0447}'. a",
    Ehms => "E, h:mm:ss '\N{U+0447}'. a",
    Gy => "y\N{U+202f}'\N{U+0433}'. G",
    GyMMM => "MM.y\N{U+202f}'\N{U+0433}'. G",
    GyMMMEd => "E, d.MM.y\N{U+202f}'\N{U+0433}'. G",
    GyMMMM => "MMMM y\N{U+202f}'\N{U+0433}'. G",
    GyMMMMEd => "E, d MMMM y\N{U+202f}'\N{U+0433}'. G",
    GyMMMMd => "d MMMM y\N{U+202f}'\N{U+0433}'. G",
    GyMMMd => "d.MM.y\N{U+202f}'\N{U+0433}'. G",
    GyMd => "dd.MM.y\N{U+202f}'\N{U+0433}'. GGGGG",
    H => "HH '\N{U+0447}'.",
    Hm => "HH:mm '\N{U+0447}'.",
    Hms => "HH:mm:ss '\N{U+0447}'.",
    Hmsv => "HH:mm:ss '\N{U+0447}'. v",
    Hmv => "HH:mm '\N{U+0447}'. v",
    M => "L",
    MEd => "E, d.MM",
    MMM => "MM",
    MMMEd => "E, d.MM",
    MMMM => "LLLL",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' W '\N{U+043e}\N{U+0442}' MMMM",
    "MMMMW-count-other" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' W '\N{U+043e}\N{U+0442}' MMMM",
    MMMMd => "d MMMM",
    MMMMdd => "d MMMM",
    MMMd => "d.MM",
    Md => "d.MM",
    d => "d",
    h => "h '\N{U+0447}'. a",
    hm => "h:mm '\N{U+0447}'. a",
    hms => "h:mm:ss '\N{U+0447}'. a",
    hmsv => "h:mm:ss '\N{U+0447}'. a v",
    hmv => "h:mm '\N{U+0447}'. a v",
    ms => "m:ss",
    y => "y\N{U+202f}'\N{U+0433}'.",
    yM => "MM.y\N{U+202f}'\N{U+0433}'.",
    yMEd => "E, d.MM.y\N{U+202f}'\N{U+0433}'.",
    yMMM => "MM.y\N{U+202f}'\N{U+0433}'.",
    yMMMEd => "E, d.MM.y\N{U+202f}'\N{U+0433}'.",
    yMMMM => "MMMM y\N{U+202f}'\N{U+0433}'.",
    yMMMMEd => "E, d MMMM y\N{U+202f}'\N{U+0433}'.",
    yMMMMd => "d MMMM y\N{U+202f}'\N{U+0433}'.",
    yMMMd => "d.MM.y\N{U+202f}'\N{U+0433}'.",
    yMd => "d.MM.y\N{U+202f}'\N{U+0433}'.",
    yQQQ => "QQQ y\N{U+202f}'\N{U+0433}'.",
    yQQQQ => "QQQQ y\N{U+202f}'\N{U+0433}'.",
    "yw-count-one" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' w '\N{U+043e}\N{U+0442}' Y '\N{U+0433}'.",
    "yw-count-other" => "'\N{U+0441}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' w '\N{U+043e}\N{U+0442}' Y '\N{U+0433}'.",
  },
  code => "bg-BG",
  date_format_full => "EEEE, d MMMM y\N{U+202f}'\N{U+0433}'.",
  date_format_long => "d MMMM y\N{U+202f}'\N{U+0433}'.",
  date_format_medium => "d.MM.y\N{U+202f}'\N{U+0433}'.",
  date_format_short => "d.MM.yy\N{U+202f}'\N{U+0433}'.",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+043f}\N{U+043d}",
    "\N{U+0432}\N{U+0442}",
    "\N{U+0441}\N{U+0440}",
    "\N{U+0447}\N{U+0442}",
    "\N{U+043f}\N{U+0442}",
    "\N{U+0441}\N{U+0431}",
    "\N{U+043d}\N{U+0434}",
  ],
  day_format_narrow => [
    "\N{U+043f}",
    "\N{U+0432}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_format_wide => [
    "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0441}\N{U+0440}\N{U+044f}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+044a}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+043a}",
    "\N{U+043f}\N{U+0435}\N{U+0442}\N{U+044a}\N{U+043a}",
    "\N{U+0441}\N{U+044a}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+043f}\N{U+043d}",
    "\N{U+0432}\N{U+0442}",
    "\N{U+0441}\N{U+0440}",
    "\N{U+0447}\N{U+0442}",
    "\N{U+043f}\N{U+0442}",
    "\N{U+0441}\N{U+0431}",
    "\N{U+043d}\N{U+0434}",
  ],
  day_stand_alone_narrow => [
    "\N{U+043f}",
    "\N{U+0432}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_stand_alone_wide => [
    "\N{U+043f}\N{U+043e}\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0432}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+043d}\N{U+0438}\N{U+043a}",
    "\N{U+0441}\N{U+0440}\N{U+044f}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+044a}\N{U+0440}\N{U+0442}\N{U+044a}\N{U+043a}",
    "\N{U+043f}\N{U+0435}\N{U+0442}\N{U+044a}\N{U+043a}",
    "\N{U+0441}\N{U+044a}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+043b}\N{U+044f}",
  ],
  era_abbreviated => [
    "\N{U+043f}\N{U+0440}.\N{U+0425}\N{U+0440}.",
    "\N{U+0441}\N{U+043b}.\N{U+0425}\N{U+0440}.",
  ],
  era_narrow => [
    "\N{U+043f}\N{U+0440}.\N{U+0425}\N{U+0440}.",
    "\N{U+0441}\N{U+043b}.\N{U+0425}\N{U+0440}.",
  ],
  era_wide => [
    "\N{U+043f}\N{U+0440}\N{U+0435}\N{U+0434}\N{U+0438} \N{U+0425}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+0430}",
    "\N{U+0441}\N{U+043b}\N{U+0435}\N{U+0434} \N{U+0425}\N{U+0440}\N{U+0438}\N{U+0441}\N{U+0442}\N{U+0430}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%x (%a) %X %Z",
  glibc_date_format => "%e.%m.%Y",
  glibc_datetime_format => "%x (%a) %X",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%k:%M:%S",
  language => "Bulgarian",
  month_format_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0443}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+044e}\N{U+043d}\N{U+0438}",
    "\N{U+044e}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043f}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+0435}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_format_narrow => [
    "\N{U+044f}",
    "\N{U+0444}",
    "\N{U+043c}",
    "\N{U+0430}",
    "\N{U+043c}",
    "\N{U+044e}",
    "\N{U+044e}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+043e}",
    "\N{U+043d}",
    "\N{U+0434}",
  ],
  month_format_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0438}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+044e}\N{U+043d}\N{U+0438}",
    "\N{U+044e}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+043e}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+044f}\N{U+043d}\N{U+0443}",
    "\N{U+0444}\N{U+0435}\N{U+0432}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+044e}\N{U+043d}\N{U+0438}",
    "\N{U+044e}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}",
    "\N{U+0441}\N{U+0435}\N{U+043f}",
    "\N{U+043e}\N{U+043a}\N{U+0442}",
    "\N{U+043d}\N{U+043e}\N{U+0435}",
    "\N{U+0434}\N{U+0435}\N{U+043a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+044f}",
    "\N{U+0444}",
    "\N{U+043c}",
    "\N{U+0430}",
    "\N{U+043c}",
    "\N{U+044e}",
    "\N{U+044e}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+043e}",
    "\N{U+043d}",
    "\N{U+0434}",
  ],
  month_stand_alone_wide => [
    "\N{U+044f}\N{U+043d}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+0444}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0443}\N{U+0430}\N{U+0440}\N{U+0438}",
    "\N{U+043c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0430}\N{U+043f}\N{U+0440}\N{U+0438}\N{U+043b}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+044e}\N{U+043d}\N{U+0438}",
    "\N{U+044e}\N{U+043b}\N{U+0438}",
    "\N{U+0430}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0441}\N{U+0435}\N{U+043f}\N{U+0442}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043e}\N{U+043a}\N{U+0442}\N{U+043e}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+043d}\N{U+043e}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
    "\N{U+0434}\N{U+0435}\N{U+043a}\N{U+0435}\N{U+043c}\N{U+0432}\N{U+0440}\N{U+0438}",
  ],
  name => "Bulgarian Bulgaria",
  native_language => "\N{U+0431}\N{U+044a}\N{U+043b}\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0441}\N{U+043a}\N{U+0438}",
  native_name => "\N{U+0431}\N{U+044a}\N{U+043b}\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0441}\N{U+043a}\N{U+0438} \N{U+0411}\N{U+044a}\N{U+043b}\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0438}\N{U+044f}",
  native_script => undef,
  native_territory => "\N{U+0411}\N{U+044a}\N{U+043b}\N{U+0433}\N{U+0430}\N{U+0440}\N{U+0438}\N{U+044f}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "2. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "3. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "4. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "2. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "3. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "4. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
  ],
  quarter_stand_alone_abbreviated => [
    "1. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "2. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "3. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
    "4. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "2. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "3. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
    "4. \N{U+0442}\N{U+0440}\N{U+0438}\N{U+043c}\N{U+0435}\N{U+0441}\N{U+0435}\N{U+0447}\N{U+0438}\N{U+0435}",
  ],
  script => undef,
  territory => "Bulgaria",
  time_format_full => "H:mm:ss '\N{U+0447}'. zzzz",
  time_format_long => "H:mm:ss '\N{U+0447}'. z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => "44.1",
}
